==> libannodex_0.5.68.orig.tar.gz: libannodex-0.5.68/src/tools/common.h <==
/*
   Copyright (C) 2003 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/** \file
 * common.h - Common routines for commandline tools
 */

#ifndef __COMMON_H__
#define __COMMON_H__

/**
 * Print a formatted error message and errno information to stderr,
 * then exit with return code 1.
 */
void exit_err (const char * fmt, ...);

/**
 * Print a formatted error message to stderr.
 */
void print_err (const char * fmt, ...);

/**
 * Print a formatted debugging message of level 'level' to stderr
 * \param level the debug level
 */
void print_debug (int level, const char * fmt, ...);

/**
 * Set the program name string as used by error and debug routines.
 */
int set_progname (const char * name);

/**
 * Increment the debug level
 */
int inc_debug_level (void);

#endif /* __COMMON_H__ */

==> libannodex_0.7.3.orig.tar.gz: libannodex-0.7.3/src/tools/common.h <==
/*
   Copyright (C) 2003 Commonwealth Scientific and Industrial Research
   Organisation (CSIRO) Australia

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of CSIRO Australia nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
   PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE ORGANISATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

/** \file
 * common.h - Common routines for commandline tools
 */

#ifndef __COMMON_H__
#define __COMMON_H__

/**
 * Close an ANNODEX, then print an error to stderr and
 * exit with return code 1
 */
void anx_exit_err (ANNODEX * anx, const char * fmt, ...);

/**
 * Print a formatted error message and errno information to stderr,
 * then exit with return code 1.
 */
void exit_err (const char * fmt, ...);

/**
 * Print a formatted error message to stderr.
 */
void print_err (const char * fmt, ...);

/**
 * Print a formatted debugging message of level 'level' to stderr
 * \param level the debug level
 */
void print_debug (int level, const char * fmt, ...);

/**
 * Get the program name for use by error and debug routines
 */
const char * get_progname (void);

/**
 * Set the program name string as used by error and debug routines.
 */
int set_progname (const char * name);

/**
 * Increment the debug level
 */
int inc_debug_level (void);

#endif /* __COMMON_H__ */
